package de.tudarmstadt.maki.simonstrator.api.uavsupport.communication;

import de.tudarmstadt.maki.simonstrator.api.component.overlay.OverlayContact;
import de.tudarmstadt.maki.simonstrator.api.component.overlay.OverlayMessage;
import de.tudarmstadt.maki.simonstrator.api.uavsupport.UAVControl;
import de.tudarmstadt.maki.simonstrator.api.uavsupport.callbacks.Callback;

/**
 * General interface for aerial overlay communication.
 * 
 * @author Julian Zobel
 *
 */
public interface AerialCommunication {

	/**
	 * Start the communication protocol
	 */
	public void start();

	/**
	 * Run a specific routing of the communication protocol.
	 * 
	 * @param cb
	 */
	public void run(Callback cb);

	/**
	 * Pause/stop a specific routing of the communication protocol.
	 */
	public void pause();

	/**
	 * Stop the communication protocol
	 */
	public void shutdown();

	/*
	 * Initialize the communication interface
	 */
	public void initialize(UAVControl control);

	/**
	 * Called if a message arrived
	 * 
	 * @param msg
	 */
	public void messageArrived(OverlayMessage msg);

	public void send(OverlayMessage msg, boolean broadcast);

	public OverlayContact getOverlayContact();
}
